DriftNativeOptions class final

Options used to open drift databases on native platforms (outside of the web).

Constructors

DriftNativeOptions({bool shareAcrossIsolates = false, bool isolateDebugLog = false, Future<String> databasePath()?, Future<Object> databaseDirectory()?, Future<String?> tempDirectoryPath()?, void isolateSetup()?, void setup(CommonDatabase db)?})
Create drift options effective when opening drift databases on native platforms.
const

Properties

databaseDirectory → Future<Object> Function()?
An optional function returning either a string or a Directory that will be used as a directory to store the database.
final
databasePath → Future<String> Function()?
An optional callback returning a custom database path to be used by drift.
final
hashCode → int
The hash code for this object.
no setterinherited
isolateDebugLog → bool
Setting the isolateDebugLog is only helpful when debugging drift itself. It will print messages exchanged between the drift isolate server and the client.
final
isolateSetup → void Function()?
An optional callback to be invoked when drift_flutter spawns a background isolate to host database connections.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
setup → void Function(CommonDatabase db)?
An optional callback to be invoked when opening an underlying database connection.
final
shareAcrossIsolates → bool
Whether two isolates opening a drift database with the name should be connected to a shared database instance.
final
tempDirectoryPath → Future<String?> Function()?
An optional callback returning a temporary directory.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited